@@ -2,6 +2,6 @@
 
 __author__ = """Tiago Lubiana"""
 __email__ = "tiago.lubiana.alves@usp.br"
-__version__ = "0.0.1"
+__version__ = '0.1.1'
 
-from .wdcuration import search_wikidata, add_key, render_qs_url, lookup_id
+from .wdcuration import search_wikidata, add_key, render_qs_url, lookup_id, today_in_quickstatements
